﻿; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Aternate States |------------------------------------------------------

[Command]
name = "Stone_Aspect"     ;Required (do not remove)
command = D, D, D, a+x
time = 60

;-| Super Motions |--------------------------------------------------------

[Command]
name = "Oteigh_Drop"     ;Required (do not remove)
command = F, B, F, b+y
time = 30

;-| Special Motions |------------------------------------------------------

[Command]
name = "Oteigh_Stunner"     ;Required (do not remove)
command = F, B, x
time = 30

[Command]
name = "Ura_Nage"     ;Required (do not remove)
command = B, F, y
time = 30

[Command]
name = "Ippon_Seionage"     ;Required (do not remove)
command = F, x+y ;x + y buttons while holding forward
time = 5 ;only allows time to tap forward, not hold it down

[Command]
name = "Tomoe_Nage"     ;Required (do not remove)
command = F, a+b ;a + b buttons while holding forward
time = 5 ;only allows time to tap forward, not hold it down

[Command]
name = "Power_Bomb"     ;Required (do not remove)
command = F, b+y ;b + y buttons while holding forward
time = 5 ;only allows time to tap forward, not hold it down

[Command]
name = "Breakout_Burst"     ;Required (do not remove)
command = F, a+x ;hold back for 1 second, then x while holding forward
time = 5 ;only allows time to tap forward, not hold it down

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;Alternate States

;---------------------------------------------------------------------------
; Stone Aspect Enter
[State -1, Stone Aspect]
type = ChangeState
value = 10602 ;switches to State 10602 (Stone Aspect - Enter)
trigger1 = command = "Stone_Aspect"
trigger1 = power >= 2000 ;2000 energy points (two stocks) are required
trigger1 = Life <= 500 ;500 health points or less are required
trigger1 = statetype = S ;Brandy most be standing
trigger1 = Var(16) = 0 ;Stone Aspect variable is 0 (Stone Aspect off)
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Stone Aspect Exit
[State -1, Stone Aspect]
type = ChangeState
value = 10603 ;switches to State 10603 (Stone Aspect - Exit)
trigger1 = command = "Stone_Aspect"
trigger1 = statetype = S ;Brandy most be standing
trigger1 = Var(16) = 1 ;Stone Aspect variable is 1 (Stone Aspect on)
trigger1 = ctrl = 1 ;player must be in control of Brandy

;===========================================================================
;Supers

;---------------------------------------------------------------------------
; Oteigh Drop (Standard)
[State -1, Oteigh Drop]
type = ChangeState
value = 3100 ;switches to State 3100 (Oteigh Drop)
triggerall = command = "Oteigh_Drop"
trigger1 = power >= 1000 ;1000 energy points (one stock) are required
trigger1 = statetype = S ;Brandy most be standing
trigger1 = Var(16) = 0 ;Stone Aspect variable is 0 (Stone Aspect off)
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Oteigh Drop (Super cancel transition)
[State -1, Oteigh Drop]
type = ChangeState
value = 3107 ;switches to State 3107 (Oteigh Drop - Super cancel transition)
triggerall = command = "Oteigh_Drop"
trigger1 = power >= 1000 ;1000 energy points (one stock) are required
trigger1 = statetype = S ;Brandy most be standing
trigger1 = Var(16) = 0 ;Stone Aspect variable is 0 (Stone Aspect off)
trigger1 = stateno = 341 ;Brandy must be in state 341 (Tomoe Nage)
trigger1 = AnimElemNo(0) >= 7 ;move must be completed on or after 7th frame
trigger1 = AnimElemNo(0) <= 13 ;move must be completed on or before 13th frame
trigger1 = RoundState = 2;players are currently in battle

;===========================================================================
;Specials

;---------------------------------------------------------------------------
; Oteigh Stunner (Brandy does this version if opponent is not already stunned)
[State -1, Oteigh Stunner (not stunned)]
type = ChangeState
value = 310 ;switches to State 310 (Stun Uppercut)
triggerall = command = "Oteigh_Stunner"
trigger1 = statetype = S ;Brandy most be standing
trigger1 = ctrl = 1 ;player must be in control of Brandy
trigger1 = p2stateno != 315 ;(opponent is not already stunned)

;---------------------------------------------------------------------------
; Oteigh Stunner (Brandy does this version if opponent is already stunned)
[State -1, Oteigh Stunner (stunned)]
type = ChangeState
value = 314 ;switches to State 314 (Stun Uppercut)
triggerall = command = "Oteigh_Stunner"
trigger1 = statetype = S ;Brandy most be standing
trigger1 = ctrl = 1 ;player must be in control of Brandy
trigger1 = p2stateno = 315 ;(opponent is already stunned)

;---------------------------------------------------------------------------
; Ippon Seionage
[State -1, Ippon Seionage]
type = ChangeState
value = 330 ;switches to State 330 (Ippon Seionage - Attempt)
triggerall = command = "Ippon_Seionage"
trigger1 = statetype = S ;Brandy most be standing
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Tomoe Nage
[State -1, Tomoe Nage]
type = ChangeState
value = 340 ;switches to State 340 (Tomoe Nage - Attempt)
triggerall = command = "Tomoe_Nage"
trigger1 = statetype = S ;Brandy most be standing
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Power Bomb
[State -1, Power Bomb]
type = ChangeState
value = 350 ;switches to State 350 (Power Bomb - Attempt)
triggerall = command = "Power_Bomb"
trigger1 = statetype = S ;Brandy most be standing
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Ura Nage
[State -1, Ura Nage]
type = ChangeState
value = 320 ;switches to State 320 (Ura Nage)
triggerall = command = "Ura_Nage"
trigger1 = statetype = S ;Brandy most be standing
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Breakout Burst
[State -1, Breakout Burst]
type = ChangeState
value = 360 ;switches to State 360 (Breakout Burst)
triggerall = command = "Breakout_Burst"
trigger1 = P2BodyDist X <= 30 ;must be 30 pixels away from opponent or closer
trigger1 = stateno = 150 ;Brandy must be in state 150 (Block)

;===========================================================================
;Standard Techniques

;---------------------------------------------------------------------------
; Hop Forward
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Hop Backward
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "s"
trigger1 = statetype != A
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Dodge
[State -1, Dodge]
type = ChangeState
value = 501
triggerall = command = "c"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Parry High
[State -1, Parry High]
type = HitOverride
triggerall = command = "fwd"
trigger1 = ctrl = 1 ;player must be in control of Brandy
trigger1 = statetype = S ;can't parry in the air
attr = SA, AA, AP ;standing and aerial, all hit attacks, all projectiles
stateno = 508 ;switches to State 508 (Parry High)
time = 15 ;parry timing window

;---------------------------------------------------------------------------
; Parry Low
[State -1, Parry Low]
type = HitOverride
triggerall = command = "downfwd"
trigger1 = ctrl = 1 ;player must be in control of Brandy
trigger1 = statetype = S ;can't parry in the air
attr = C, AA, AP ;crouching, all hit attacks, all projectiles
stateno = 509 ;switches to State 509 (Parry Low)
time = 15 ;parry timing window

;===========================================================================
;Standard Attacks

;---------------------------------------------------------------------------
; Low Palm Thrust
[State -1, Low Palm Thrust]
type = ChangeState
value = 217
triggerall = command = "x"
trigger1 = statetype = S
trigger1 = p2bodydist X < 5 ;must be closer than five pixels from opponent
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Kata Guruma
[State -1, Kata Guruma]

;type = ChangeState
;value = 800
;triggerall = command = "y" || command = "z"
;triggerall = statetype = S
;triggerall = ctrl
;triggerall = stateno != 100
;trigger1 = command = "holdfwd"
;trigger1 = p2bodydist X < 10
;trigger1 = (p2statetype = S) || (p2statetype = C)
;trigger1 = p2movetype != H
;trigger2 = command = "holdback"
;trigger2 = p2bodydist X < 10
;trigger2 = (p2statetype = S) || (p2statetype = C)
;trigger2 = p2movetype != H

type = ChangeState
value = 218 ;switches to State 218 (Kata Guruma)
triggerall = command = "fwd_y"
trigger1 = statetype = S ;must be standing on the ground
trigger1 = p2bodydist X < 20 ;must be closer than twenty pixels from opponent
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Low Palm Thrust
[State -1, Low Palm Thrust]
type = ChangeState
value = 219
triggerall = command = "a"
trigger1 = statetype = S
trigger1 = P2BodyDist X < 5 ;must be closer than five pixels from opponent
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Osoto Gari
[State -1, Osoto Gari]
type = ChangeState
value = 220 ;switches to State 220 (Osoto Gari)
triggerall = command = "fwd_b"
trigger1 = statetype = S ;must be standing on the ground
trigger1 = P2BodyDist X < 10 ;must be closer than ten pixels from opponent
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; High Palm Thrust
[State -1, Standing Light Punch]
type = ChangeState
value = 201
triggerall = command = "x"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Overhand Chop
[State -1, Standing Hard Punch]
type = ChangeState
value = 202
triggerall = command = "y"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Knee Kick
[State -1, Standing Light Kick]
type = ChangeState
value = 203
triggerall = command = "a"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Front Kick
[State -1, Standing Hard Kick]
type = ChangeState
value = 204
triggerall = command = "b"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Crouch - Palm Thrust
[State -1, Crouching Light Punch]
type = ChangeState
value = 213
triggerall = command = "x"
trigger1 = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Crouch - Side Chop
[State -1, Crouching Hard Punch]
type = ChangeState
value = 214
triggerall = command = "y"
trigger1 = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Crouch - Ground Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 215
triggerall = command = "a"
trigger1 = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Brandy

;---------------------------------------------------------------------------
; Crouch - Foot Sweep
[State -1, Crouching Hard Kick]
type = ChangeState
value = 216
triggerall = command = "b"
trigger1 = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Brandy

